Class: RakeAudit::ApplicationController
- Inherits:
-
ActionController::Base
- Object
- ActionController::Base
- RakeAudit::ApplicationController
- Defined in:
- app/controllers/rake_audit/application_controller.rb
Overview
Base controller for every RakeAudit Web UI page.
It installs the pluggable authentication hook as a before_action. When the host application has configured Configuration#authenticate_with with a callable, that callable is run in the controller instance’s context on every request (so it may call host helpers such as authenticate_admin! or redirect_to). When authenticate_with is nil, the hook is a no-op and all pages are publicly accessible.